[![tests](https://github.com/ifsm/apollon/actions/workflows/tests.yml/badge.svg)](
https://github.com/ifsm/apollon/actions/workflows/tests.yml)

# Apollon
Apollon is a Python framework for audio feature extraction and music similarity
estimation. It includes subpackages for

* Audio feature extraction
* Hidden Markov Models
* Self-Organizing Map

## 1. Installation
### 1.1 Install from PyPI
The latest version of apollon is available on PyPI. Just open a terminal an run
the following command to download and install apollon:

```
pip install apollon
```

We currently provide wheels for macOS and Windows; GNU/Linux users have to
build apollon from source.

## 2. Documentation
Full [documentation](https://apollon.readthedocs.io) is available on readthedocs.
